[![CI](https://github.com/bouweandela/snakemake-storage-plugin-rucio/actions/workflows/ci.yml/badge.svg?branch=main)](https://github.com/bouweandela/snakemake-storage-plugin-rucio/actions/workflows/ci.yml?query=branch%3Amain)
[![codecov](https://codecov.io/gh/bouweandela/snakemake-storage-plugin-rucio/graph/badge.svg?token=GRYFT0TCRQ)](https://codecov.io/gh/bouweandela/snakemake-storage-plugin-rucio)
[![Docs](https://readthedocs.org/projects/snakemake/badge/?version=latest)](https://snakemake.github.io/snakemake-plugin-catalog/plugins/storage/rucio.html)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.15657667.svg)](https://doi.org/10.5281/zenodo.15657667)

# snakemake-storage-plugin-rucio

A Snakemake storage plugin that handles files available through [Rucio](https://rucio.cern.ch/).

## Contributing

Contributions are very welcome. Instruction on how to get started are available
in the [contribution guidelines](CONTRIBUTING.md).
